@@ -7,7 +7,7 @@ Phone configuration wizard
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2009 Michal Čihař
+Copyright © 2003 - 2010 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -180,7 +180,7 @@ class PhoneSearchPage(Wammu.Wizard.TextPage):
             self.edit.Clear()
             self.edit.AppendText(_('Wammu is now searching for phone:') + '\n')
             self.thread = Wammu.PhoneSearch.AllSearchThread(
-                    lock = 'no',
+                    lock = False,
                     callback = self.SearchDone,
                     msgcallback = self.SearchMessage,
                     noticecallback = self.SearchNotice,
@@ -233,7 +233,7 @@ class PhoneSearchPage(Wammu.Wizard.TextPage):
             choices = []
             for phone in self.results:
                 choices.append(
-                    _('Model %(model)s (%(manufacturer)s) on %(port)s device using connection %(connection)s') %
+                    _('Phone %(manufacturer)s %(model)s on device %(port)s using connection %(connection)s') %
                     {
                         'model': phone[2][0],
                         'manufacturer': phone[3],
@@ -257,7 +257,7 @@ class PhoneSearchPage(Wammu.Wizard.TextPage):
             self.parent.settings.SetGammuDriver(config[1])
             self.edit.AppendText(_('Following phone will be used:') + '\n')
             self.edit.AppendText(
-                _('Model %(model)s (%(manufacturer)s) on %(port)s device using connection %(connection)s') %
+                _('Phone %(manufacturer)s %(model)s on device %(port)s using connection %(connection)s') %
                 {
                     'model': config[2][0],
                     'manufacturer': config[3],
@@ -600,7 +600,5 @@ class WizardApp(wx.App):
             vendor = 'Michal Čihař'
         self.SetVendorName(vendor)
 
-        wx.InitAllImageHandlers()
-
         # Return a success flag
         return True
