@@ -7,7 +7,7 @@ Misc functions like charset conversion, entries parsers,..
 __author__ = 'Michal Čihař'
 __email__ = 'michal@cihar.com'
 __license__ = '''
-Copyright © 2003 - 2009 Michal Čihař
+Copyright © 2003 - 2010 Michal Čihař
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License version 2 as published by
@@ -401,7 +401,7 @@ def ParseMessage(msg, parseinfo = False):
             loc = loc + ', '
         loc = loc + str(i['Location'])
     try:
-        tmp = StrConv(txt)
+        StrConv(txt)
         msg['Text'] = txt
     except:
         s2 = ''
@@ -439,7 +439,7 @@ def ProcessMessages(list, synced):
 
     return {'read':read, 'unread':unread, 'sent':sent, 'unsent':unsent}
 
-def FormatError(txt, info):
+def FormatError(txt, info, gammu_config = None):
     if info['Code'] == gammu.Errors['ERR_NOTSUPPORTED']:
         message = _('Your phone doesn\'t support this function.')
     elif info['Code'] == gammu.Errors['ERR_NOTIMPLEMENTED']:
@@ -457,11 +457,26 @@ def FormatError(txt, info):
     elif info['Code'] == gammu.Errors['ERR_TIMEOUT']:
         message = _('Timeout while trying to communicate with phone. Maybe phone is not connected (for cable) or out of range (for Bluetooth or IrDA).')
     elif info['Code'] == gammu.Errors['ERR_DEVICENOTEXIST']:
-        message = _('Device for communication with phone does not exist. Maybe you don\'t have phone plugged or your configuration is wrong.')
+        if gammu_config is None:
+            message = _('Device for communication with phone does not exist. Maybe you don\'t have phone plugged or your configuration is wrong.')
+        else:
+            message = _('Device "%s" for communication with phone does not exist. Maybe you don\'t have phone plugged or your configuration is wrong.') % gammu_config['Device']
     elif info['Code'] == gammu.Errors['ERR_DEVICENOPERMISSION']:
-        message = _('Can not access device for communication with phone.')
-        if sys.platform == 'linux2':
-            message += ' ' + _('Maybe you need to be member of some group to have acces to device.')
+        if sys.platform[:5] == 'linux':
+            message_group = ' ' + _('Maybe you need to be member of some group to have acces to device.')
+        else:
+            message_group = ''
+        if gammu_config is None:
+            message = _('Can not access device for communication with phone.')
+        else:
+            check = CheckDeviceNode(gammu_config['Device'])
+            if check[0] == -2:
+                message = check[3]
+                message_group = ''
+            else:
+                message = _('Can not access device "%s" for communication with phone.') % gammu_config['Device']
+        if message_group != '':
+            message += ' ' + message_group
     elif info['Code'] == gammu.Errors['ERR_NOSIM']:
         message = _('Can not access SIM card. Please check whether it is properly inserted in phone and/or try to reboot the phone by removing battery.')
     else:
@@ -478,8 +493,9 @@ def FixupMaskedEdit(edit):
 def GetWebsiteLang():
     (loc, charset) = locale.getdefaultlocale()
     try:
-        if loc[:2].lower() == 'cs':
-            return 'cs.'
+        lang = loc[:2].lower()
+        if lang in ('cs', 'de', 'es', 'fr', 'sk'):
+            return '%s.' % lang
         return ''
     except TypeError:
         return ''
@@ -546,3 +562,44 @@ def CheckDeviceNode(curdev):
                 (_('Maybe you need to be member of %s group.') % group)
                 )
     return (0, '', '', '')
+
+def CompatConfig(cfg):
+    '''
+    Adjust configuration for possible changes in Gammu history.
+    '''
+
+    # 1.27.0 changed handling of boolean options
+    # Pre 1.27.0 used strings
+    if tuple(map(int, gammu.Version()[1].split('.'))) < (1, 27, 0):
+        if cfg['SyncTime']:
+            cfg['SyncTime'] = 'yes'
+        else:
+            cfg['SyncTime'] = 'no'
+        if cfg['LockDevice']:
+            cfg['LockDevice'] = 'yes'
+        else:
+            cfg['LockDevice'] = 'no'
+        if cfg['StartInfo']:
+            cfg['StartInfo'] = 'yes'
+        else:
+            cfg['StartInfo'] = 'no'
+    # 1.27.0 accepted only numbers
+    if tuple(map(int, gammu.Version()[1].split('.'))) == (1, 27, 0):
+        if cfg['SyncTime']:
+            cfg['SyncTime'] = 1
+        else:
+            cfg['SyncTime'] = 0
+        if cfg['LockDevice']:
+            cfg['LockDevice'] = 1
+        else:
+            cfg['LockDevice'] = 0
+        if cfg['StartInfo']:
+            cfg['StartInfo'] = 1
+        else:
+            cfg['StartInfo'] = 0
+
+    # Older versions did not use model auto
+    if cfg['Model'] == 'auto':
+        cfg['Model'] = ''
+
+    return cfg
